const GLib = imports.gi.GLib;
const Gtk = imports.gi.Gtk;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const GTK_VERSION = Gtk.get_major_version();

function init() {
}

function buildPrefsWidget() {
    let widget = new PrefsWidget();
    	if(GTK_VERSION == 3) {
    		widget.widget.show_all(); }
    		
    return widget.widget;
}

class PrefsWidget {
    constructor() {
        this._settings = ExtensionUtils.getSettings();

        this.widget = new Gtk.Box({
            orientation: Gtk.Orientation.VERTICAL,
        });

        this.vbox = new Gtk.Box({
            orientation: Gtk.Orientation.VERTICAL,
            hexpand: true,
        });
        
        if(GTK_VERSION == 3) {
        	this.vbox.add(this.adjustIconSize());
        	this.vbox.add(this.resetButton());
        	this.vbox.add(new Gtk.Separator({ orientation: Gtk.Orientation.HORIZONTAL, margin_bottom: 10, margin_top: 10 }));
        	this.vbox.add(this.tip());
        	this.vbox.add(this.command());
        	this.vbox.add(this.helpImage());
        	
        	this.widget.add(this.vbox);        
        }
        
        else if(GTK_VERSION == 4) {
        	this.vbox.append(this.adjustIconSize());
        	this.vbox.append(this.resetButton());
        	this.vbox.append(new Gtk.Separator({ orientation: Gtk.Orientation.HORIZONTAL, margin_bottom: 10, margin_top: 10 }));
        	this.vbox.append(this.tip());
        	this.vbox.append(this.command());
        	this.vbox.append(this.helpImage());
        	
        this.widget.append(this.vbox);
    	}
    }    	
    	

adjustIconSize() {
        let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5 });
        let adjust_label = new Gtk.Label({ label: "Adjust Icon Size", xalign: 0, hexpand: true });

        this.setSize = new Gtk.SpinButton();
	this.setSize.set_range(8, 32);
	this.setSize.set_value(this._settings.get_int('icon-size'));
	this.setSize.set_increments(2, 4);
	this.setSize.connect('value-changed', (entry) => { this._settings.set_int('icon-size', entry.get_value()); });
	
	if(GTK_VERSION == 3) {
		hbox.add(adjust_label);
		hbox.add(this.setSize); }
		
	else if(GTK_VERSION == 4) {
		hbox.append(adjust_label);
		hbox.append(this.setSize); }

        return hbox;
    }
    
resetButton() {
    	let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5, halign: Gtk.Align.CENTER  });
    	this.resetButton = new Gtk.Button();
        this.resetButton.set_label("Reset to Extensions's Default Size By Cliking this Button");
        this.resetButton.connect('clicked', ()=> { this._settings.set_int('icon-size', 16);
        this.setSize.set_value(this._settings.get_int('icon-size'));});
	
	if(GTK_VERSION == 3) {
		hbox.add(this.resetButton); }
	else if(GTK_VERSION == 4) {
		hbox.append(this.resetButton) }

        return hbox;
    } 
    
tip() {
    	let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5, halign: Gtk.Align.CENTER  });
    	let tipLabel = new Gtk.Label({ label:
    	"you can tweak the colors of these system menu buttons by edititng this extensions stylesheet.css file \nrun below command to open the styles sheet file.", xalign: 0, hexpand: true });
    	
    	if(GTK_VERSION == 3) {
		hbox.add(tipLabel); }
	else if(GTK_VERSION == 4) {
		hbox.append(tipLabel); }
		
        return hbox;
    }     
    
command() {
    	let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5, halign: Gtk.Align.CENTER  });
    	let command = new Gtk.Label({ label: "gedit $HOME/.local/share/gnome-shell/extensions/roundedSystemMenuButtons@pratap.fastmail.fm/stylesheet.css", selectable: true, xalign: 0, hexpand: true });
    	
    	if(GTK_VERSION == 3) {
		hbox.add(command); }
        else if(GTK_VERSION == 4) {
        	hbox.append(command) }
      	
      	return hbox;
    }    
    
helpImage() {
    	let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5 });
        let image1 = new Gtk.Image({file: Me.dir.get_path()+'/1.png', halign: Gtk.Align.FILL, valign: Gtk.Align.FILL, hexpand: true, vexpand: true });
    	
    	if(GTK_VERSION == 3) {
		hbox.add(image1); }
        else if(GTK_VERSION == 4) {
        	hbox.append(image1) }
      	
      	return hbox;
    }
}
